# `campy`: Stanford's Graphical Libraries in Python

![GitHub Top Language](https://img.shields.io/github/languages/top/sredmond/campy.svg)
![GitHub Issues](https://img.shields.io/github/issues/sredmond/campy.svg)
![GitHub License](https://img.shields.io/github/license/sredmond/campy.svg)
![PyPI](https://img.shields.io/pypi/v/campy.svg)
![PyPI - Status](https://img.shields.io/pypi/status/campy.svg)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/campy.svg)

## Features

- All your favorite `GObject`s, like `GOval`s, `GRect`s, and more.
- Functional event-driving GUIs.
- I/O helpers.
- Cross-platform support.


## Installation

To install `campy`, simply use `pip`:

```
$ pip install campy
```

## Documentation

Learn more about `campy` at `https://campy.sredmond.io/`.
